@@ -5,6 +5,15 @@ geometry
 
 .. currentmodule:: compas.geometry
 
+Base Class
+==========
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    Geometry
+
 Classes
 =======
 
@@ -828,6 +837,9 @@ if not compas.IPY:
         world_to_local_coordinates_numpy,
         local_to_world_coordinates_numpy
     )
+
+from .geometry import Geometry
+
 from .primitives import (  # noqa: E402
     Primitive,
     Bezier,
@@ -1201,9 +1213,8 @@ __all__ = [
     'trimesh_remesh_along_isoline',
     'trimesh_slice',
 
-    'KDTree',
+    'Geometry',
 
-    'Pointcloud',
     'Primitive',
     'Bezier',
     'Circle',
@@ -1226,6 +1237,9 @@ __all__ = [
     'Sphere',
     'Torus',
 
+    'Pointcloud',
+    'KDTree',
+
     'Projection',
     'Reflection',
     'Rotation',
