@@ -72,6 +72,7 @@ __all__ = [
     'draw_lines',
     'draw_geodesics',
     'draw_polylines',
+    'draw_breps',
     'draw_faces',
     'draw_cylinders',
     'draw_pipes',
@@ -87,7 +88,7 @@ def wrap_drawfunc(f):
     def wrapper(*args, **kwargs):
         layer = kwargs.get('layer', None)
         clear = kwargs.get('clear', False)
-        redraw = kwargs.get('redraw', True)
+        redraw = kwargs.get('redraw', False)
         if layer:
             if not rs.IsLayer(layer):
                 create_layers_from_path(layer)
@@ -109,7 +110,7 @@ def wrap_drawfunc(f):
 
 @wrap_drawfunc
 def draw_labels(labels, **kwargs):
-    """Draw labels as text dots and optionally set individual font, fontsize, name and color.
+    """Draw labels as text dots and optionally set individual font, fontsize, name, layer and color.
 
     Parameters
     ----------
@@ -131,6 +132,7 @@ def draw_labels(labels, **kwargs):
             'text': And(str, len),
             Optional('name', default=''): str,
             Optional('color', default=None): (lambda x: len(x) == 3 and all(0 <= y <= 255 for y in x)),
+            Optional('layer', default=None): str,
             Optional('fontsize', default=10): Or(int, float),
             Optional('font', default="Arial Regular"): str
         })
@@ -142,6 +144,7 @@ def draw_labels(labels, **kwargs):
         text = label['text']
         name = label.get('name', '')
         color = label.get('color', None)
+        layer = label.get('layer')
         size = label.get('fontsize', 10)
         font = label.get('font', 'Arial Regular')
         dot = TextDot(str(text), Point3d(*pos))
@@ -159,6 +162,10 @@ def draw_labels(labels, **kwargs):
             attr.ColorSource = ColorFromObject
         else:
             attr.ColorSource = ColorFromLayer
+        if layer and find_layer_by_fullpath:
+            index = find_layer_by_fullpath(layer, True)
+            if index >= 0:
+                attr.LayerIndex = index
         attr.Name = name
         obj.CommitChanges()
         guids.append(guid)
@@ -421,7 +428,7 @@ def draw_polylines(polylines, **kwargs):
 
 
 @wrap_drawfunc
-def draw_breps(faces, srf=None, u=10, v=10, trim=True, tangency=True, spacing=0.1, flex=1.0, pull=1.0, **kwargs):
+def draw_breps(faces, srf=None, u=10, v=10, trim=True, tangency=True, spacing=0.1, flex=1.0, pull=1.0, join=False, **kwargs):
     """Draw polygonal faces as Breps, and optionally set individual name, color,
     and layer properties.
 
@@ -443,6 +450,8 @@ def draw_breps(faces, srf=None, u=10, v=10, trim=True, tangency=True, spacing=0.
     spacing : float, optional
     flex : float, optional
     pull : float, optional
+    join : bool, optional
+        Join the individual faces as polysurfaces. Default is False.
 
     Returns
     -------
@@ -461,24 +470,43 @@ def draw_breps(faces, srf=None, u=10, v=10, trim=True, tangency=True, spacing=0.
             Optional('layer', default=None): str,
         })
 
+    Examples
+    --------
+    Using a compas Mesh as an example:
+
+    >>> from compas.datastructures import Mesh
+    >>> from compas.geometry import Box, Frame
+    >>> from compas_rhino.utilities import draw_breps
+    >>> box = Box(Frame.worldXY(), 1.0, 2.0, 3.0)
+    >>> mesh = Mesh.from_shape(box)
+
+    Draw convert each mesh face to brep dict schema:
+
+    >>> vertices = mesh.vertices_attributes('xyz')
+    >>> breps = [{'points': mesh.face_coordinates(face)} for face in mesh.faces()]
+
+    Draw brep faces as one joined brep.
+
+    >>> guids = draw_breps(breps, join=True)
+
     """
-    guids = []
+    breps = []
     for f in iter(faces):
         points = f['points']
         name = f.get('name', '')
         color = f.get('color')
         layer = f.get('layer')
-        corners = [Point3d(*point) for point in points]
+        corners = [Point3d(*point) for point in points + points[:1]]
         pcurve = PolylineCurve(corners)
         geo = List[GeometryBase](1)
         geo.Add(pcurve)
         p = len(points)
-        if p == 4:
+        if p == 3:
             brep = Brep.CreateFromCornerPoints(Point3d(*points[0]),
                                                Point3d(*points[1]),
                                                Point3d(*points[2]),
                                                TOL)
-        elif p == 5:
+        elif p == 4:
             brep = Brep.CreateFromCornerPoints(Point3d(*points[0]),
                                                Point3d(*points[1]),
                                                Point3d(*points[2]),
@@ -486,8 +514,14 @@ def draw_breps(faces, srf=None, u=10, v=10, trim=True, tangency=True, spacing=0.
                                                TOL)
         else:
             brep = Brep.CreatePatch(geo, u, v, TOL)
-        if not brep:
-            continue
+        if brep:
+            breps.append(brep)
+
+    if join:
+        breps = Brep.JoinBreps(breps, TOL)
+
+    guids = []
+    for brep in breps:
         guid = add_brep(brep)
         if not guid:
             continue
@@ -938,12 +972,3 @@ def draw_circles(circles, **kwargs):
         obj.CommitChanges()
         guids.append(guid)
     return guids
-
-
-# ==============================================================================
-# Main
-# ==============================================================================
-
-if __name__ == '__main__':
-
-    pass
